You are viewing a plain text version of this content. The canonical link for it is here.
Posted to github@arrow.apache.org by "alamb (via GitHub)" <gi...@apache.org> on 2025/06/28 10:30:42 UTC

Re: [PR] [Variant] Speedup `ObjectBuilder` (62x faster) [arrow-rs]

alamb commented on PR #7808:
URL: https://github.com/apache/arrow-rs/pull/7808#issuecomment-3015169260

   Thanks for this @friendlymatthew  -- I think before we embark on optimizing performance we should probably have some benchmarks to define what we are optimizing
   
   Here are some initial ones I would suggest I think are important:
   
   1. Create a lot of Variant objects with the same field names but different values
   
   Aka build this variant over and over again :
   
   ```json
   { 
     "user": "random",
     "age": 54,
     "comment": "this is a long string that will not fit in short string but is also random",
     "categories": ["red", "blue", "green"],
   }
   ```
   
   2. Create a VariantList with 1 to 100 copies of the above objects
   
   There are probably other cases too  but that might be a good place to start
   


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: github-unsubscribe@arrow.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org